#! /usr/bin/python
# -*- coding: utf-8 -*-
#
#    autostart.py - Manages creation/deletion of an autostart entry.
#
#    Copyright  2005-07 Adolfo González Blázquez <code@infinicode.org>
#               2011 PhobosK <phobosk@kbfx.net>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#    MA 02110-1301, USA.

"""Manages the autostart entry for the main application."""

import os
import sys

from cameramonitor import camglobals as glob
from cameramonitor import utils

__authors__ = "Adolfo González Blázquez <code@infinicode.org>, PhobosK <phobosk@kbfx.net>"
__copyright__ = "Copyright 2005-11, Adolfo González Blázquez and PhobosK"
__license__ = "GPL"
__version__ = "0.3.2"
__maintainer__ = "PhobosK <phobosk@kbfx.net>"
__status__ = "Development"

debug = 0

data = """[Desktop Entry]
Name=%s
Comment=%s
Icon=%s
Exec=%s/%s
Terminal=false
Type=Application
Categories=""" % \
    (glob.name_long, glob.name_long, glob.logo, glob.bin_dir, glob.name)

filename = os.environ["HOME"] + '/.config/autostart/' + glob.name  + '.desktop'


def create_autostart_file():
    """Creates an autostart desktop file.

    If something goes wrong, shows more info on the raised error when in debug mode.

    @return: True on success, False on failure
    @rtype: Bool
    """
    try:
        if not os.path.exists(filename):
            f = open(filename,"w")
            f.writelines(data)
            f.close()
            os.chmod(filename, 0700)
    except:
        if debug:
            print  "[autostart]: Error creating: %s" % filename
            print  sys.exc_info()

        utils.display_dialog_error(glob.message_cannot_add_autostart + "\n\n" \
                + "<i>" + glob.message_check_debug_output + "</i>")
        return False

    else: return True


def delete_autostart_file():
    """Removes the autostart desktop file.

    If something goes wrong, shows more info on the raised error when in debug mode.

    @return: True on success, False on failure
    @rtype: Bool
    """
    try:
        if os.path.exists(filename):
            os.remove(filename)
    except:
        if debug:
            print  "[autostart]: Error deleting: %s" % filename
            print  sys.exc_info()

        utils.display_dialog_error(glob.message_cannot_remove_autostart + "\n\n" \
                + "<i>" + glob.message_check_debug_output + "</i>")
        return False

    else: return True


if __name__ == "__main__":
    print "Description: \n%s" % __doc__
    print "Version: %s" % __version__
    print "Authors: %s" % __authors__
