#! /usr/bin/python
# -*- coding: utf-8 -*-
#
#    camglobals.py - Holds the global options for the package.
#
#    Copyright  2005-07 Adolfo González Blázquez <code@infinicode.org>
#               2011 PhobosK <phobosk@kbfx.net>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#    MA 02110-1301, USA.

"""Holds some global variables needed for the package.

    - Uses gettext module for internationalisation.
    - We do not use setlocale() 'cause it is thread not safe anyway.
    - Messages, labels, hints etc. are here to be in one place, so it is easier
      to maintain.
    - Debug messages are not processed, so we have an unified output to report
      bug debugs.
"""

import gettext
import locale

__authors__ = "Adolfo González Blázquez <code@infinicode.org>, PhobosK <phobosk@kbfx.net>"
__copyright__ = "Copyright 2005-11, Adolfo González Blázquez and PhobosK"
__license__ = "GPL"
__version__ = "0.3.2"
__maintainer__ = "PhobosK <phobosk@kbfx.net>"
__status__ = "Development"

name = "cameramonitor"
name_long = "Camera Monitor"
authors = ["Adolfo González Blázquez <code@infinicode.org>", "PhobosK <phobosk@kbfx.net>"]
website = "http://www.infinicode.org/code/cameramonitor/"
version = __version__

bin_dir = "/usr/bin"
pixmaps_dir = "/usr/share/cameramonitor"
locale_dir = "/usr/share/locale"


# Set proper internationalisation
langs = []

lc, encoding = locale.getdefaultlocale( \
    ['LC_ALL', 'LC_MESSAGES', 'LANGUAGE', 'LANG', 'LC_CTYPE'])
if (lc):
    langs = [lc]

langs += ["en"] # This is a fallback we always have 'translated'

gettext.bindtextdomain(name, locale_dir)
gettext.textdomain(name)
lang = gettext.translation(name, locale_dir, languages=langs, fallback = True)
_ = lang.gettext


description = _("A little monitor to check if your Webcam is On")

image = {}
image["on"] = pixmaps_dir+'/cameramonitor_on.png'
image["off"] = pixmaps_dir+'/cameramonitor_off.png'
image["none"] = pixmaps_dir+'/cameramonitor_none.png'
image["unknown"] = pixmaps_dir+'/cameramonitor_unknown.png'
logo = pixmaps_dir+'/cameramonitor.png'

tooltip = {}
tooltip["on"] = _("Camera is ON")
tooltip["off"] = _("Camera is OFF")
tooltip["none"] = _("No Camera is available")
tooltip["unknown"] = _("Camera status is UNKNOWN")

copyright = 'Copyright © 2005-10 Adolfo González Blázquez and PhobosK'

license = "This program is free software; you can redistribute it and/or modify \
it under the terms of the GNU General Public License as published by \
the Free Software Foundation; either version 2 of the License, or \
(at your option) any later version. \n\n\
This program is distributed in the hope that it will be useful, but \
WITHOUT ANY WARRANTY; without even the implied warranty of \
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. \
See the GNU General Public License for more details. \n\n\
You should have received a copy of the GNU General Public License \
along with this program; if not, write to the Free Software Foundation, Inc., \
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA."

gconf_path = '/apps/cameramonitor'
gconf_key_video_device = gconf_path + '/video_device'
gconf_key_notify = gconf_path + '/notify'
gconf_key_autostart = gconf_path + '/autostart'
gconf_key_icon_visible = gconf_path + '/visible'

video_device_default = '/dev/video0'
icon_visible_default = True
notify_default = True
autostart_default = False


message_no_permission_to_use_camera = \
                    _("You don't have permissions to use the camera!")
message_verify_device_permissions = \
                    _("Please verify your permissions on the video device:")
message_verify_device_path_permissions = \
            _("Please verify your permissions on the path to the video device:")
hint_add_to_video_group = _("Maybe you need to add yourself to the video group.")
message_will_watch_device = _("We will watch the device though.")
message_will_not_watch_device = _("We will not watch this device at all!")
message_video_device = _("Video device:")
message_cannot_add_autostart = _("Cannot add to autostart!")
message_cannot_remove_autostart = _("Cannot remove from autostart!")
message_check_debug_output = _("Check the debug output to find out why.")
title_preferences = _("Preferences")
label_device_path = _("Webcam device path")
label_visibility = _("Visibility")
label_show_tray = _("Always show tray icon")
label_notify = _("Notification")
label_always_notify = _("Show notification when camera is switched")
label_autostart = _("Autostart")
label_always_autostart = _("Autostart with every session")


if __name__ == "__main__":
    print "Description: \n%s" % __doc__
    print "Version: %s" % __version__
    print "Authors: %s" % __authors__
